# Feature Guide

This section provides an overview of the features implemented in vLLM Ascend. Developers can refer to this guide to understand how vLLM Ascend works.

:::{toctree}
:caption: Feature Guide
:maxdepth: 1
patch
ModelRunner_prepare_inputs
disaggregated_prefill
eplb_swift_balancer.md
Multi_Token_Prediction
ACL_Graph
KV_Cache_Pool_Guide
add_custom_aclnn_op
:::
